---
name: Bug Report
about: Report a bug in the Neo4j GraphRAG library
labels: "bug"
---

<!--
    If you are an Enterprise customer, you might want to head over to our
    [Customer Support Portal](https://support.neo4j.com/).
-->

<!--
    If you are unsure about the usage of the library, this issue tracker is not
    the right place to ask. Please use one of the following channels instead:

    - Neo4j Online Community: https://community.neo4j.com/
    - StackOverflow: https://stackoverflow.com/questions/tagged/neo4j+python
    - Discord: https://discord.gg/neo4j
    - Neo4j Support Portal if you are an enterprise customer:
      https://support.neo4j.com/
-->

<!--
    Make sure you've searched the issue tracker for similar issues first.
-->


# Bug Report
<!-- description of the found bug -->


# My Environment
Python Version: <!-- output of `python -VV` -->
Driver Version: <!-- can be found with `python -m pip show neo4j` -->
Server Version and Edition: <!-- e.g., Neo4j 4.4.3 enterprise cluster -->
Operating System: <!-- e.g., Windows 10, Ubuntu 18.04, macOS 10.15 -->
